django-tutelary
======================================

|build-status-image| |pypi-version|

Overview
--------

Policy-based permissions for Django.

Requirements
------------

-  Python (3.5)
-  Django (1.9)

Installation
------------

.. note:: django-tutelary is not yet released to PyPI.  Please install
          directly from GitHub for now.

Install using ``pip``:

.. code:: bash

    $ pip install django-tutelary

Usage
-----

Refer to the `documentation <http://django-tutelary.readthedocs.org/>`_
for further details!

.. |build-status-image| image:: https://secure.travis-ci.org/Cadasta/django-tutelary.svg?branch=master
   :target: http://travis-ci.org/Cadasta/django-tutelary?branch=master
.. |pypi-version| image:: https://img.shields.io/pypi/v/django-tutelary.svg
   :target: https://pypi.python.org/pypi/django-tutelary
